#!/usr/bin/env python3
#
# Copyright (c) 2015,Thibault Saunier <thibault.saunier@collabora.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
# Boston, MA 02110-1301, USA.

LIBDIR = r'/clangarm64/lib'
DATADIR = r'/clangarm64/share'
BUILDDIR = r'C:/M/B/src/build-CLANGARM64'
SRCDIR = r'C:/M/B/src/gst-devtools-1.24.12'
GST_VALIDATE_TESTSUITE_VERSION = '1.24'
